==> opensaml-soap-impl-3.4.0-sources.jar: org/opensaml/soap/wssecurity/impl/EncodedStringImpl.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wssecurity.impl;

import org.opensaml.soap.wssecurity.EncodedString;

/**
 * Implementation of {@link EncodedString}.
 */
public class EncodedStringImpl extends AttributedStringImpl implements EncodedString {
    
    /** The encodingType attribute value. */
    private String encodingType;

    /**
     * Constructor.
     * 
     * @param namespaceURI namespace of the element
     * @param elementLocalName name of the element
     * @param namespacePrefix namespace prefix of the element
     */
    public EncodedStringImpl(final String namespaceURI, final String elementLocalName, final String namespacePrefix) {
        super(namespaceURI, elementLocalName, namespacePrefix);
    }

    /** {@inheritDoc} */
    public String getEncodingType() {
        return encodingType;
    }

    /** {@inheritDoc} */
    public void setEncodingType(final String newEncodingType) {
        encodingType = prepareForAssignment(encodingType, newEncodingType);
    }

}

==> opensaml-soap-impl-5.1.6-sources.jar: org/opensaml/soap/wssecurity/impl/EncodedStringImpl.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wssecurity.impl;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.opensaml.soap.wssecurity.EncodedString;

/**
 * Implementation of {@link EncodedString}.
 */
public class EncodedStringImpl extends AttributedStringImpl implements EncodedString {
    
    /** The encodingType attribute value. */
    @Nullable private String encodingType;

    /**
     * Constructor.
     * 
     * @param namespaceURI namespace of the element
     * @param elementLocalName name of the element
     * @param namespacePrefix namespace prefix of the element
     */
    public EncodedStringImpl(@Nullable final String namespaceURI, @Nonnull final String elementLocalName,
            @Nullable final String namespacePrefix) {
        super(namespaceURI, elementLocalName, namespacePrefix);
    }

    /** {@inheritDoc} */
    @Nullable public String getEncodingType() {
        return encodingType;
    }

    /** {@inheritDoc} */
    public void setEncodingType(@Nullable final String newEncodingType) {
        encodingType = prepareForAssignment(encodingType, newEncodingType);
    }

}
